import planer, json
np = planer.pal

source = ['https://gitee.com/imagepy/planer-store/attach_files/690786/download/resnet18.pla',
          'https://gitee.com/imagepy/planer-store/attach_files/690789/download/imagenet_labs.json',
          'https://gitee.com/imagepy/planer-store/attach_files/690790/download/bus.jpg']

root = '/'.join(__file__.split('\\')[:-1])

def load():
    globals()['net'] = planer.read_net(root+'/resnet18')
    with open(root+'/imagenet_labs.json') as f:
        globals()['classes'] = json.load(f)

def recognize(img):
    img = planer.asarray(img)
    x = planer.resize(img, (224, 224))
    x = x[None, :,:,:].astype('float32')
    x = (x/255).transpose(0, 3, 1, 2)
    y = np.argmax(net(x), axis=-1)
    return classes[str(y)]

def show():
    import matplotlib.pyplot as plt
    from PIL import Image
    img = Image.open(root+'/bus.jpg')
    img = np.asnumpy(img)
    rst = recognize(img)
    plt.imshow(img.astype('uint8'))
    plt.title(rst)
    plt.show()
    
if __name__ == '__main__':
    load()
    show()



import planer
np = planer.pal

source = ['https://gitee.com/imagepy/planer-store/attach_files/689491/download/crnn-ocr.pla',
          'https://gitee.com/imagepy/planer-store/attach_files/689699/download/planer.jpg']

root = '/'.join(__file__.split('\\')[:-1])

dic = ''' !@#$%&()+-:,.'"/\\?0123456789abcdefghijklmnopqrstuvwxyz'''

def load():
    globals()['net'] = planer.read_net(root+'/crnn-ocr')
    
def greedy_search(raw, blank=0):
    max_id = raw.argmax(2).ravel()
    msk = max_id[1:] != max_id[:-1]
    max_id = max_id[1:][msk]
    return max_id[max_id!=blank]

def recognize(img):
    img = planer.asarray(img)
    x = img.astype('float32')
    if x.ndim==3: x=x.mean(-1)
    w = 48*x.shape[1]//x.shape[0]
    x = planer.resize(x, (48, w))
    x = (x - 0.5)/(90/255)
    y = net(x[None, None, :, :])
    pred = greedy_search(y)
    pred = [dic[i] for i in pred.tolist()]
    return ''.join(pred)

def show():
    import matplotlib.pyplot as plt
    from PIL import Image
    img = Image.open(root+'/planer.jpg')
    img = np.asnumpy(img)
    text = recognize(img)
    plt.imshow(img)
    plt.title(text)
    plt.show()
    
if __name__ == '__main__':
    load()
    show()



import os, os.path as osp
import importlib, planer
from tqdm import tqdm
import urllib.request

root = osp.abspath(osp.dirname(__file__))

def progress(i, n, bar=[None]):
    if bar[0] is None:
        bar[0] = tqdm()
    bar[0].total = n
    bar[0].update(i-bar[0].n)
    if n==i: bar[0] = None
   
def download(url, path, info=print, progress=progress):
    info('download from %s'%url)
    urllib.request.urlretrieve(url, path,
        lambda a,b,c: progress(int(100.0 * a * b/c), 100))

def downloads(src, path, info=print, progress=progress):
    for i in src: download(i, path+'/'+osp.split(i)[-1], info, progress)
      
def load_model(name, auto=True):
    model = importlib.import_module('.'+name+'.main', 'planer_store')
    model.download = lambda : downloads(model.source, root+'/'+name)
    has = lambda i: osp.exists(root+'/'+name+'/'+osp.split(i)[-1])
    if auto: downloads([i for i in model.source if not has(i)], root+'/'+name)
    model.load()
    return model

def core(obj): planer.core(obj)

def test():
    load_model('crnn_ocr').show()
    load_model('face_68_key').show()
    load_model('hed_edge').show()
    load_model('obj_recognize').show()
    load_model('super_resolution').show()
    load_model('cellpose').show()

if __name__ == '__main__':
    import sys
    sys.path.append('../')
    test()



from setuptools import setup, find_packages

descr = """Some useful models based on planer"""

if __name__ == '__main__':
    setup(name='planer-store',
        version='0.11',
        url='https://github.com/Image-Py/planer-store',
        description='toolbox of planer',
        long_description=descr,
        author='Y.Dong, YXDragon',
        author_email='yxdragon@imagepy.org',
        license='BSD 3-clause',
        packages=find_packages(),
        package_data={},
        install_requires=[
            'planer',
            'tqdm'
        ],
    )



import planer
np = planer.pal

source = ['https://gitee.com/imagepy/planer-store/attach_files/690801/download/hed.pla',
          'https://gitee.com/imagepy/planer-store/attach_files/690800/download/plane.jpg']

root = '/'.join(__file__.split('\\')[:-1])

def load():
    globals()['net'] = planer.read_net(root+'/hed')

def hed_edge(img, size=64):
    img = planer.asarray(img, dtype='float32')
    x.reshape((-1, 3))[:] -= np.array([104, 117, 123])
    x = x.transpose(2, 0, 1)[None, :, :, :]
    return np.asnumpy(planer.resize(net(x)[0], (h,w)))

@planer.tile(glob=32)
def hed_edge(img):
    x = img.transpose(2,0,1)[None, :, :, :]
    d = np.array([104, 117, 123])[:,None,None]
    return net(x - d)[0]

def show():
    import matplotlib.pyplot as plt
    from PIL import Image
    img = Image.open(root+'/plane.jpg')
    img = planer.asnumpy(img)
    edge = hed_edge(img)
    plt.subplot(121).imshow(img)
    plt.subplot(122).imshow(edge)
    plt.show()

if __name__ == '__main__':
    load()
    show()
    



import planer, json
np = planer.pal

source = ['https://gitee.com/imagepy/planer-store/attach_files/690791/download/ESRGAN.pla',
          'https://gitee.com/imagepy/planer-store/attach_files/690797/download/girl.png']

root = '/'.join(__file__.split('\\')[:-1])

def load():
    globals()['net'] = planer.read_net(root+'/ESRGAN')


def super_resolution(img):
    img = planer.asarray(img)
    x = (img/255.0).transpose(2, 0, 1)
    x = x[None, :, :, :].astype('float32')
    y = net(x).transpose(1, 2, 0)
    return planer.asnumpy(y)
    
def show():
    import matplotlib.pyplot as plt
    from PIL import Image
    img = Image.open(root+'/girl.png')
    img = np.asnumpy(img)
    rst = super_resolution(img)
    plt.subplot(121).imshow(img.astype('uint8'))
    plt.subplot(122).imshow(rst.clip(0,1))
    plt.show()
    
if __name__ == '__main__':
    load()
    show()
